import 'dart:io';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:text_input_todo_app/create_page.dart';
import 'package:text_input_todo_app/todo_card.dart';
import 'package:text_input_todo_app/app_route.dart';
import 'package:text_input_todo_app/task_store.dart';
import 'package:text_input_todo_app/done_card.dart';

void main() {
  runApp(const MainPage());
}

class MainPage extends StatelessWidget {
  const MainPage({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Task App',
      routes: {
        AppRoute.todoPage : (context) => const TaskPage(),
        AppRoute.createPage : (context) => const CreatePage(),
      },
      home: const TaskPage(),
    );
  }
}

class TaskPage extends StatefulWidget {
  const TaskPage({super.key});

  @override
  State<TaskPage> createState() => _TaskPageState();
}

class _TaskPageState extends State<TaskPage> {

  int _selectedIndex = 0;

  List<bool> pageWidgets = [false, true];

  @override
  Widget build(BuildContext context) {
    var isDone = pageWidgets[_selectedIndex];
    var todoList = TaskStore().taskList.where((task) => task.done == isDone).toList();
    return Scaffold(
      backgroundColor: const Color.fromRGBO(165, 190, 215, 1.0),
      appBar: AppBar(
        title: Text(isDone ? 'Done List' : 'Task List'),
        actions: <Widget>[
          Visibility(
              visible: Platform.isIOS,
              child: IconButton(
                icon: const Icon(CupertinoIcons.add),
                onPressed: (){
                  var createPageRoute = MaterialPageRoute(
                      builder: (BuildContext context) {
                        return const CreatePage();
                      },
                      fullscreenDialog: true
                  );
                  Navigator.of(context).push(createPageRoute);
                },
              ),
          ),
        ],
      ),
      body: SafeArea(
        child: ListView.builder(
          itemCount: todoList.length,
          itemBuilder: (BuildContext context, int index) {
            var title = todoList[index].title;
            var id = todoList[index].index;

            var todoCard = TodoCard(
                title: title,
                onPressedComplete: () => _complete(id),
                onPressedDelete: () => _delete(id)
            );
            var doneCard = DoneCard(
                title: title,
                onPressedDelete: () => _delete(id)
            );
            return isDone ? doneCard : todoCard;
          },
        ),
      ),
      floatingActionButton: Visibility(
        visible: Platform.isAndroid,
        child: FloatingActionButton(
          child: const Icon(Icons.add),
          onPressed: () {
            Navigator.of(context).pushNamed(AppRoute.createPage);
          },
        ),
      ),
      bottomNavigationBar: BottomNavigationBar(
        items: const [
          BottomNavigationBarItem(
            icon: Icon(Icons.folder_open),
            label: 'task',
          ),
          BottomNavigationBarItem(
            icon: Icon(Icons.done),
            label: 'done',
          ),
        ],
        currentIndex: _selectedIndex,
        selectedItemColor: Colors.orangeAccent,
        onTap: (int index) {
          setState(() {
            _selectedIndex = index;
          });
        },
      ),
    );
  }

  void _delete(int index) {
    setState(() {
      TaskStore().delete(index);
    });
  }

  void _complete(int index) {
    setState(() {
      TaskStore().complete(index);
    });
  }
}
